def compare_version(v1: str, v2: str):
    """
    标准版本号比较
    :param v1:
    :param v2:
    :return: v1>v2 返回1, v1<v2 返回v1<v2, 否则返回0
    """

    v1l = v1.split('.')
    v2l = v2.split('.')

    for i in range(3):
        i1 = int(v1l[i])
        i2 = int(v2l[i])
        if i1 == i2:
            continue
        if i1 > i2:
            return 1
        else:
            return -1

    return 0


def max_version(*args):
    """

    :param args:
    :return:
    """
    max = None
    for arg in args:
        if max is None:
            max = arg
            continue
        if compare_version(max, arg) == -1:
            max = arg
    return max


def min_version(*args):
    """

    :param args:
    :return:
    """
    min = None
    for arg in args:
        if min is None:
            min = arg
            continue
        if compare_version(min, arg) == 1:
            min = arg
    return min



__title__ = 'pxy'

__description__ = 'tools of python'
__url__ = 'https://github.com/foyoux/pxy'
__version__ = '0.0.8'
__author__ = 'foyou'
__author_email__ = 'yimi.0822@qq.com'
__license__ = 'GPL-3.0'
__copyright__ = f'Copyright 2021 {__author__}'
__ide__ = 'PyCharm - https://www.jetbrains.com/pycharm/'

from .sub import *

__all__ = [
    'split_list',
    'compare_version', 'max_version', 'min_version',
]



from typing import List


def split_list(obj_list: List, sub_size: int = 128) -> List[list]:
    """
    split list
    :param obj_list: list object
    :param sub_size: sub list size
    :return: List[list]
    """
    if not isinstance(obj_list, list):
        return [[obj_list]]
    if sub_size < 1:
        sub_size = 1
    return [obj_list[i:i + sub_size] for i in range(0, len(obj_list), sub_size)]



from pxy import compare_version, max_version, min_version


def test_compare_version():
    assert compare_version('0.0.3', '0.0.1') == 1
    assert compare_version('0.0.3', '0.0.3') == 0
    assert compare_version('0.0.3', '1.0.1') == -1


def test_max_version():
    assert max_version('0.0.1', '0.2.0', '0.2.0') == '0.2.0'


def test_min_version():
    assert min_version('0.0.1', '0.2.0', '0.2.0') == '0.0.1'
    assert min_version('1.0.1', '0.2.0', '0.2.0') == '0.2.0'
